@@ -60,6 +60,8 @@ enum
 	COLUMN_AUTORUN_ITEM_TYPE,	
 };
 
+static gboolean should_autorun_mount (GMount *mount);
+
 void
 nautilus_autorun_get_preferences (const char *x_content_type, 
 				  gboolean *pref_ask, 
@@ -846,6 +848,10 @@ _g_mount_guess_content_type_finish (GMount              *mount,
 
 /*- END MOVE TO GIO ---*/
 
+enum {
+	AUTORUN_DIALOG_RESPONSE_EJECT = 0
+};
+
 typedef struct
 {
 	GtkWidget *dialog;
@@ -913,6 +919,13 @@ static void
 autorun_dialog_response (GtkDialog *dialog, gint response, AutorunDialogData *data)
 {
 	switch (response) {
+	case AUTORUN_DIALOG_RESPONSE_EJECT:
+		nautilus_file_operations_unmount_mount (GTK_WINDOW (dialog),
+							data->mount,
+							data->should_eject,
+							FALSE);
+		break;
+
 	case GTK_RESPONSE_NONE:
 		/* window was closed */
 		break;
@@ -1137,8 +1150,8 @@ show_dialog:
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 	
 	if (g_mount_can_eject (mount)) {
-		eject_button = gtk_button_new_with_mnemonic (_("_Eject"));
 		GtkWidget *eject_image;
+		eject_button = gtk_button_new_with_mnemonic (_("_Eject"));
 		pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
 						   "media-eject",
 						   nautilus_get_icon_size_for_stock_size (GTK_ICON_SIZE_BUTTON),
@@ -1152,7 +1165,7 @@ show_dialog:
 		eject_button = gtk_button_new_with_mnemonic (_("_Unmount"));
 		data->should_eject = FALSE;
 	}
-	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), eject_button, 0);
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), eject_button, AUTORUN_DIALOG_RESPONSE_EJECT);
 	gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (GTK_DIALOG (dialog)->action_area), eject_button, TRUE);
 
 	/* show the dialog */
@@ -1221,8 +1234,9 @@ autorun_guessed_content_type_callback (GObject *source_object,
 	}
 
 	/* only open the folder once.. */
-	if (open_folder)
+	if (open_folder) {
 		autorun_open_folder_for_mount (data);
+	}
 
 	g_object_unref (data->mount);
 	g_free (data);
@@ -1233,10 +1247,10 @@ nautilus_autorun (GMount *mount, NautilusAutorunOpenWindow open_window_func, gpo
 {
 	AutorunData *data;
 
-	if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_MEDIA_AUTORUN_NEVER))
+	if (!should_autorun_mount (mount) ||
+	    eel_preferences_get_boolean (NAUTILUS_PREFERENCES_MEDIA_AUTORUN_NEVER)) {
 		return;
-		
-	/* TODO: only do this for local mounts */
+	}
 
 	/* Sniff the newly added mount to generate x-content/ types;
 	 * we do this asynchronously (in another thread) since it
@@ -1270,3 +1284,105 @@ nautilus_autorun_get_x_content_types_for_mount (GMount      *mount,
 	 */
 	return _g_mount_guess_content_type (mount, force_rescan, NULL);
 }
+
+
+static GList *inhibit_mount_handling_for = NULL;
+
+
+static gboolean
+remove_inhibit_file_cb (gpointer data)
+{
+	GFile *file = data;
+	GList *l;
+
+	l = g_list_find (inhibit_mount_handling_for, file);
+	if (l != NULL) {
+		inhibit_mount_handling_for = g_list_delete_link (inhibit_mount_handling_for, l);
+		g_object_unref (file);
+	}
+	
+	return FALSE;
+}
+
+void
+nautilus_inhibit_autorun_for_file (GFile *file)
+{
+	inhibit_mount_handling_for = g_list_prepend (inhibit_mount_handling_for, g_object_ref (file));
+	g_timeout_add_full (0,
+			    5000,
+			    remove_inhibit_file_cb,
+			    g_object_ref (file),
+			    g_object_unref);
+}
+
+static gboolean
+remove_inhibit_volume (gpointer data)
+{
+	GVolume *volume = data;
+
+	g_object_set_data (G_OBJECT (volume), "nautilus-inhibit-autorun", NULL);
+	return FALSE;
+}
+
+void
+nautilus_inhibit_autorun_for_volume (GVolume *volume)
+{
+	g_object_set_data (G_OBJECT (volume), "nautilus-inhibit-autorun", GINT_TO_POINTER (1));
+	g_timeout_add_full (0,
+			    5000,
+			    remove_inhibit_volume,
+			    g_object_ref (volume),
+			    g_object_unref);
+}
+
+static gboolean
+should_autorun_mount (GMount *mount)
+{
+	GFile *root, *file;
+	GList *l;
+	GVolume *enclosing_volume;
+	gboolean ignore_autorun;
+
+	ignore_autorun = FALSE;
+	enclosing_volume = g_mount_get_volume (mount);
+	if (enclosing_volume != NULL) {
+		if (g_object_get_data (G_OBJECT (enclosing_volume), "nautilus-inhibit-autorun") != NULL) {
+			ignore_autorun = TRUE;
+			g_object_set_data (G_OBJECT (enclosing_volume), "nautilus-inhibit-autorun", NULL);
+		}
+	}
+
+	if (ignore_autorun) {
+		if (enclosing_volume != NULL) {
+			g_object_unref (enclosing_volume);
+		}
+		return FALSE;
+	}
+	
+	root = g_mount_get_root (mount);
+
+	for (l = inhibit_mount_handling_for; l != NULL; l = l->next) {
+		file = l->data;
+		if (g_file_has_prefix (file, root)) {
+			ignore_autorun = TRUE;
+			
+			inhibit_mount_handling_for = g_list_delete_link (inhibit_mount_handling_for, l);
+			g_object_unref (file);
+			
+			break;
+		}
+	}
+
+	/* only do autorun on local files or files where g_volume_should_automount() returns TRUE */
+	ignore_autorun = TRUE;
+	if (g_file_is_native (root) || 
+	    (enclosing_volume != NULL && g_volume_should_automount (enclosing_volume))) {
+		ignore_autorun = FALSE;
+	}
+	if (enclosing_volume != NULL) {
+		g_object_unref (enclosing_volume);
+	}
+	g_object_unref (root);
+
+	return !ignore_autorun;
+}
