@@ -155,9 +155,9 @@ nautilus_bookmark_compare_with (gconstpointer a, gconstpointer b)
 		return 1;
 	}
 
-	if (g_file_equal (bookmark_a->details->location,
-			  bookmark_b->details->location)) {
-		return 0;
+	if (!g_file_equal (bookmark_a->details->location,
+			   bookmark_b->details->location)) {
+		return 1;
 	}
 	
 	return 0;
@@ -471,7 +471,7 @@ nautilus_bookmark_set_icon_to_default (NautilusBookmark *bookmark)
 NautilusBookmark *
 nautilus_bookmark_new (GFile *location, const char *name)
 {
-	return nautilus_bookmark_new_with_icon (location, name, FALSE, NULL);
+	return nautilus_bookmark_new_with_icon (location, name, TRUE, NULL);
 }
 
 static void
