@@ -30,7 +30,6 @@
 #include <libnautilus-private/nautilus-icon-canvas-item.h>
 #include <libnautilus-private/nautilus-icon-container.h>
 #include <libnautilus-private/nautilus-icon-dnd.h>
-#include <libnautilus-private/nautilus-icon-factory.h>
 
 /* An Icon. */
 
@@ -43,6 +42,14 @@ typedef struct {
 
 	/* X/Y coordinates. */
 	double x, y;
+
+	/*
+	 * In RTL mode x is RTL x position, we use saved_ltr_x for
+	 * keeping track of x value before it gets converted into
+	 * RTL value, this is used for saving the icon position 
+	 * to the nautilus metafile. 
+	 */
+	 double saved_ltr_x;
 	
 	/* Scale factor (stretches icon). */
 	double scale;
@@ -75,7 +82,7 @@ typedef struct {
 	guint timer_id;
 
 	guint prev_x, prev_y;
-	ArtDRect prev_rect;
+	EelDRect prev_rect;
 	int last_adj_y;
 } NautilusIconRubberbandInfo;
 
