@@ -59,6 +59,7 @@ struct _NautilusProgressInfo
 	gboolean activity_mode;
 	gboolean started;
 	gboolean finished;
+	gboolean paused;
 	
 	GSource *idle_source;
 	gboolean source_is_now;
@@ -192,6 +193,17 @@ delete_event (GtkWidget *widget,
 	return TRUE;
 }
 
+static void
+status_icon_activate_cb (GtkStatusIcon *icon,
+			 GtkWidget *progress_window)
+{
+	if (GTK_WIDGET_VISIBLE (progress_window)) {
+		gtk_widget_hide (progress_window);
+	} else {
+		gtk_window_present (GTK_WINDOW (progress_window));
+	}
+}
+
 static GtkWidget *
 get_progress_window (void)
 {
@@ -210,8 +222,8 @@ get_progress_window (void)
 			      _("File operations"));
 	gtk_window_set_wmclass (GTK_WINDOW (progress_window),
 				"file_progress", "Nautilus");
-	gtk_window_set_type_hint (GTK_WINDOW (progress_window),
-				  GDK_WINDOW_TYPE_HINT_DIALOG);
+	gtk_window_set_position (GTK_WINDOW (progress_window),
+				 GTK_WIN_POS_CENTER_ALWAYS);
 	
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
@@ -223,7 +235,9 @@ get_progress_window (void)
 	g_signal_connect (progress_window, "delete_event", (GCallback)delete_event, NULL);
 
 	status_icon = gtk_status_icon_new_from_icon_name ("stock_folder-copy");
-	g_signal_connect_swapped (status_icon, "activate", (GCallback)gtk_window_present, progress_window);
+	g_signal_connect (status_icon, "activate",
+			  (GCallback)status_icon_activate_cb,
+			  progress_window);
 
 	gtk_status_icon_set_visible (status_icon, FALSE);
 	
@@ -423,6 +437,9 @@ handle_new_progress_info (NautilusProgressInfo *info)
 static gboolean
 new_op_started_timeout (NautilusProgressInfo *info)
 {
+	if (nautilus_progress_info_get_is_paused (info)) {
+		return TRUE;
+	}
 	if (!nautilus_progress_info_get_is_finished (info)) {
 		handle_new_progress_info (info);
 	}
@@ -567,6 +584,20 @@ nautilus_progress_info_get_is_finished (NautilusProgressInfo *info)
 	return res;
 }
 
+gboolean
+nautilus_progress_info_get_is_paused (NautilusProgressInfo *info)
+{
+	gboolean res;
+	
+	G_LOCK (progress_info);
+	
+	res = info->paused;
+	
+	G_UNLOCK (progress_info);
+	
+	return res;
+}
+
 static gboolean
 idle_callback (gpointer data)
 {
@@ -666,6 +697,30 @@ queue_idle (NautilusProgressInfo *info, gboolean now)
 	}
 }
 
+void
+nautilus_progress_info_pause (NautilusProgressInfo *info)
+{
+	G_LOCK (progress_info);
+
+	if (!info->paused) {
+		info->paused = TRUE;
+	}
+
+	G_UNLOCK (progress_info);
+}
+
+void
+nautilus_progress_info_resume (NautilusProgressInfo *info)
+{
+	G_LOCK (progress_info);
+
+	if (info->paused) {
+		info->paused = FALSE;
+	}
+
+	G_UNLOCK (progress_info);
+}
+
 void
 nautilus_progress_info_start (NautilusProgressInfo *info)
 {
@@ -784,18 +839,27 @@ nautilus_progress_info_pulse_progress (NautilusProgressInfo *info)
 
 void
 nautilus_progress_info_set_progress (NautilusProgressInfo *info,
-				     double                current_percent)
+				     double                current,
+				     double                total)
 {
-	G_LOCK (progress_info);
+	double current_percent;
+	
+	if (total <= 0) {
+		current_percent = 1.0;
+	} else {
+		current_percent = current / total;
 
-	if (current_percent < 0) {
-		current_percent	= 0;
-	}
+		if (current_percent < 0) {
+			current_percent	= 0;
+		}
 		
-	if (current_percent > 1.0) {
-		current_percent	= 1.0;
+		if (current_percent > 1.0) {
+			current_percent	= 1.0;
+		}
 	}
 	
+	G_LOCK (progress_info);
+	
 	if (info->activity_mode || /* emit on switch from activity mode */
 	    fabs (current_percent - info->progress) > 0.005 /* Emit on change of 0.5 percent */
 	    ) {
