@@ -44,7 +44,6 @@
 #include <gtk/gtkcheckmenuitem.h>
 #include <glib/gi18n.h>
 #include <libgnome/gnome-util.h>
-#include <libgnomevfs/gnome-vfs.h>
 #include <libnautilus-private/nautilus-desktop-icon-file.h>
 #include <libnautilus-private/nautilus-directory-background.h>
 #include <libnautilus-private/nautilus-directory-notify.h>
@@ -568,6 +567,8 @@ fm_desktop_icon_view_init (FMDesktopIconView *desktop_icon_view)
 	
 	/* Set our default layout mode */
 	nautilus_icon_container_set_layout_mode (icon_container,
+						 gtk_widget_get_direction (GTK_WIDGET(icon_container)) == GTK_TEXT_DIR_RTL ?
+						 NAUTILUS_ICON_LAYOUT_T_B_R_L :
 						 NAUTILUS_ICON_LAYOUT_T_B_L_R);
 
 	g_signal_connect_object (icon_container, "middle_click",
@@ -782,8 +783,8 @@ fm_desktop_icon_view_create (NautilusWindowInfo *window)
 
 static gboolean
 fm_desktop_icon_view_supports_uri (const char *uri,
-			   GnomeVFSFileType file_type,
-			   const char *mime_type)
+				   GFileType file_type,
+				   const char *mime_type)
 {
 	if (g_str_has_prefix (uri, EEL_DESKTOP_URI)) {
 		return TRUE;
