@@ -1421,37 +1421,37 @@ fm_icon_view_start_renaming_file (FMDirectoryView *view,
 }
 
 static const GtkActionEntry icon_view_entries[] = {
-  { "Arrange Items", NULL, N_("Arran_ge Items") }, /* name, stock id, label */
-  { "Stretch", NULL,                               /* name, stock id */
-    N_("Str_etch Icon"), NULL,                     /* label, accelerator */
-    N_("Make the selected icon stretchable"),      /* tooltip */ 
-    G_CALLBACK (action_stretch_callback) },
-  { "Unstretch", NULL,                               /* name, stock id */
-    N_("Restore Icons' Original Si_zes"), NULL,                     /* label, accelerator */
-    N_("Restore each selected icon to its original size"),      /* tooltip */ 
-    G_CALLBACK (action_unstretch_callback) },
-  { "Clean Up", NULL,                               /* name, stock id */
-    N_("Clean _Up by Name"), NULL,                     /* label, accelerator */
-    N_("Reposition icons to better fit in the window and avoid overlapping"),      /* tooltip */ 
-    G_CALLBACK (action_clean_up_callback) },
+  /* name, stock id, label */  { "Arrange Items", NULL, N_("Arran_ge Items") }, 
+  /* name, stock id */         { "Stretch", NULL,
+  /* label, accelerator */       N_("Str_etch Icon"), NULL,
+  /* tooltip */                  N_("Make the selected icon stretchable"),
+                                 G_CALLBACK (action_stretch_callback) },
+  /* name, stock id */         { "Unstretch", NULL,
+  /* label, accelerator */       N_("Restore Icons' Original Si_zes"), NULL,
+  /* tooltip */                  N_("Restore each selected icon to its original size"),
+                                 G_CALLBACK (action_unstretch_callback) },
+  /* name, stock id */         { "Clean Up", NULL,
+  /* label, accelerator */       N_("Clean _Up by Name"), NULL,
+  /* tooltip */                  N_("Reposition icons to better fit in the window and avoid overlapping"),
+                                 G_CALLBACK (action_clean_up_callback) },
 };
 
 static const GtkToggleActionEntry icon_view_toggle_entries[] = {
-  { "Tighter Layout", NULL,                               /* name, stock id */
-    N_("Compact _Layout"), NULL,                     /* label, accelerator */
-    N_("Toggle using a tighter layout scheme"),      /* tooltip */ 
-    G_CALLBACK (action_tighter_layout_callback),
-    0 },
-  { "Reversed Order", NULL,                               /* name, stock id */
-    N_("Re_versed Order"), NULL,                     /* label, accelerator */
-    N_("Display icons in the opposite order"),      /* tooltip */ 
-    G_CALLBACK (action_reversed_order_callback),
-    0 },
-  { "Keep Aligned", NULL,                               /* name, stock id */
-    N_("_Keep Aligned"), NULL,                     /* label, accelerator */
-    N_("Keep icons lined up on a grid"),      /* tooltip */ 
-    G_CALLBACK (action_keep_aligned_callback),
-    0 },
+  /* name, stock id */      { "Tighter Layout", NULL,
+  /* label, accelerator */    N_("Compact _Layout"), NULL,
+  /* tooltip */               N_("Toggle using a tighter layout scheme"),
+                              G_CALLBACK (action_tighter_layout_callback),
+                              0 },
+  /* name, stock id */      { "Reversed Order", NULL,
+  /* label, accelerator */    N_("Re_versed Order"), NULL,
+  /* tooltip */               N_("Display icons in the opposite order"),
+                              G_CALLBACK (action_reversed_order_callback),
+                              0 },
+  /* name, stock id */      { "Keep Aligned", NULL,
+  /* label, accelerator */    N_("_Keep Aligned"), NULL,
+  /* tooltip */               N_("Keep icons lined up on a grid"),
+                              G_CALLBACK (action_keep_aligned_callback),
+                              0 },
 };
 
 static const GtkRadioActionEntry arrange_radio_entries[] = {
@@ -1682,6 +1682,16 @@ fm_icon_view_using_manual_layout (FMDirectoryView *view)
 	return !fm_icon_view_using_auto_layout (FM_ICON_VIEW (view));
 }
 
+static void
+fm_icon_view_widget_to_file_operation_position (FMDirectoryView *view,
+						GdkPoint *position)
+{
+	g_assert (FM_IS_ICON_VIEW (view));
+
+	nautilus_icon_container_widget_to_file_operation_position
+		(get_icon_container (FM_ICON_VIEW (view)), position);
+}
+
 static void
 icon_container_activate_callback (NautilusIconContainer *container,
 				  GList *file_list,
@@ -1888,6 +1898,9 @@ static gboolean
 should_preview_sound (NautilusFile *file)
 {
 	GFile *location;
+	GFilesystemPreviewType use_preview;
+
+	use_preview = nautilus_file_get_filesystem_use_preview (file);
 
 	location = nautilus_file_get_location (file);
 	if (g_file_has_uri_scheme (location, "burn")) {
@@ -1902,10 +1915,23 @@ should_preview_sound (NautilusFile *file)
 	}
 		
 	if (preview_sound_auto_value == NAUTILUS_SPEED_TRADEOFF_ALWAYS) {
-		return TRUE;
+		if (use_preview == G_FILESYSTEM_PREVIEW_TYPE_NEVER) {
+			return FALSE;
+		} else {
+			return TRUE;
+		}
 	}
 	
-	return nautilus_file_is_local (file);
+	if (use_preview == G_FILESYSTEM_PREVIEW_TYPE_NEVER) {
+		/* file system says to never preview anything */
+		return FALSE;
+	} else if (use_preview == G_FILESYSTEM_PREVIEW_TYPE_IF_LOCAL) {
+		/* file system says we should treat file as if it's local */
+		return TRUE;
+	} else {
+		/* only local files */
+		return nautilus_file_is_local (file);
+	}
 }
 
 static int
@@ -2584,6 +2610,7 @@ fm_icon_view_class_init (FMIconViewClass *klass)
         fm_directory_view_class->text_attribute_names_changed = fm_icon_view_text_attribute_names_changed;
         fm_directory_view_class->update_menus = fm_icon_view_update_menus;
 	fm_directory_view_class->using_manual_layout = fm_icon_view_using_manual_layout;
+	fm_directory_view_class->widget_to_file_operation_position = fm_icon_view_widget_to_file_operation_position;
 
 	klass->clean_up = fm_icon_view_real_clean_up;
 	klass->supports_auto_layout = real_supports_auto_layout;
